=====
cards
=====


.. image:: https://img.shields.io/pypi/v/cards.svg
        :target: https://pypi.python.org/pypi/cards

.. image:: https://img.shields.io/travis/okken/cards.svg
        :target: https://travis-ci.org/okken/cards

.. image:: https://ci.appveyor.com/api/projects/status/hk18x9ovqv3d7kpw?svg=true
    :target: https://ci.appveyor.com/project/okken/cards

.. image:: https://readthedocs.org/projects/cards-project/badge/?version=latest
        :target: https://cards-project.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/okken/cards/shield.svg
     :target: https://pyup.io/repos/github/okken/cards/
     :alt: Updates



Project task tracking / todo list

This is a demo application being built in conjunction with
the `Test & Code podcast <http://testandcode.com>`__.

We'll be building up this application, and testing it, and adding
functionality, while discussing software testing and development
practices.

Follow along, starting with `episode 37 <http://testandcode.com/37>`__.


* Free software: MIT license
* Documentation: https://cards-project.readthedocs.io.


Features
--------

* TODO



